#ifndef DVDPREVIEW_H
#define DVDPREVIEW_H

#include <objbase.h>
#include "includes.h"


class CDVDPreview
{
public:
	CDVDPreview::CDVDPreview();
	CDVDPreview::~CDVDPreview();


	// Initialize the preview class. Pass the handle of the parent window, 
	// the horizontal and vertical video scaling factors, and the
	// initial position of the video display in the parent view coordinates.
	// The function returns the handle of the child window where the video will display
	// You need to do this before you use any of the functions below...
	// Set ShowWindow = SW_HIDE to not display the video window.
	// Set VideoOnly = true to display the video only, not the slider nor the buttons.
	// Set VideoScaleY to -1 to get an automatic y-axis scaling, according to the DAR in the video. 
	// You can pass WindowStyle to control the style of the created video window.
	// If NoOverlay = 1, the video is displayed using bitmap calls. Otherwise, the hardware overlay
	// buffer is used, if available, which is faster.
	HWND	InitPreview(HWND ParentWindow, float VideoScaleX, float VideoScaleY, int PosX, int PosY,
		UINT ShowWindow = SW_SHOW, BOOL VideoOnly = false, UINT WindowStyle = WS_CHILD, BOOL NoOverlay = FALSE);

	// This loads the video file. Returns a non zero value if something when wrong while opening the file.
	// Note, however, that the file header is loaded in a another thread, so a zero return does not always
	// mean that the file was loaded successfully. To check that, you should add
	// WaitForThread() and CheckErrorFlag().
	// If LoadAll is true, all the vob files after FileName in the same domain are loaded.
	// For example, when loading VTS_01_1.VOB, then VTS_01_2.VOB, VTS_01_3.VOB ... will be loaded.
	// If VTS_01_0.VOB is loaded, no other file is (since it's in the VTSM domain).
	// Set Refresh to false to NOT display the first frame of the video.
	int	LoadFile(char* FileName, bool LoadAll = true, bool Refresh = true);
	// This will return DVD2AVI error flag. This is useful for example when loading a file. A non-zero
	// error flag indicates an error during the loading. Make sure you call that AFTER WaitForThread().
	int	CheckErrorFlag();

	// Use this to close all the VOB files.
	void CloseFile();

	// Set the video scaling factor. Larger than 1 means enlarging.
	// This is how you would recalculate the size needed for the parent window.
	// RECT VideoRect;
	// RECT ParentRect;
	// ::GetWindowRect(m_PreviewHWnd,&VideoRect);	// screen coordinates.
	// GetWindowRect(&ParentRect);					// screen coordinates.
	// Resize the parent window.	
	// SetWindowPos(NULL,0,0, VideoRect.right-ParentRect.left, VideoRect.bottom - ParentRect.top,SWP_NOMOVE|SWP_NOZORDER);
	// NOTE: if VideoScaleY == -1 (default) the y-axis scaling factor is decucted from the x-axis
	// scaling factor, according to the aspect-ratio stored in the video.
	void	SetVideoScaling(float VideoScaleX, float VideoScaleY = -1);
	// Here, you can set the x-axis scaling factor. The y-axis is determined from the supplied DAR, and
	// the size of the video in the VOB. If DisplayAspectRatio is -1, the DAR in the video stream is used.
	void	SetVideoScaling(float VideoScaleX, int DisplayAspectRatio);

	// ShowSliderAndButtons(false) hides the slider and buttons in the video window.
	void	ShowSliderAndButtons(bool Show);

	// You can call this function to "send" a message to the video previewer. No windows message
	// is actually sent.
	LRESULT HandleMessage(UINT message, WPARAM wParam, LPARAM lParam);

	// VideoPreview is multithreaded, which means the class usually returns the hand right away, then
	// processes in another thread. You can call this function to block until the thread is done executing.
	// This is useful when issuing several comands in a row (for example via HandleMessage());
	void	WaitForThread();

	// This saves the current video image to a file after opening a "Save" dialog. 
	// If FileName != NULL, the save dialog isn't opened. A scaling of 1 is used if XDownSamp and
	// YDownSamp are not specifed. XDownSamp and YDownSamp must be larger than 1, and result
	// in a smaller image. If SavePPM is 1, the picture is saved as a PPM file instead of a BMP.
	void	SaveBMPFile(char* FileName = NULL, float XDownSamp = 1, float YDownSamp = 1, int SavePPM = 0);

	// This starts and stops playback.
	void	Play();
	void	Stop();
	// You can use this to set a sector at which playback will stop. Use -1 to not stop.
	void	SetStopSector(int Sector);

	// Go to sector. Returns sector at actual video frame. Set Display = 0 to avoid displaying
	// the frame (good for simple seeks). Set it to -1 so the image isn't even decoded.
	long	GoToSector(long SectorNum, int Display = 1);

	// Use this to select whether images will be displayed, decoded, or neither:
	// 1 is decoded and displayed. 0 is decoded but not displayed. -1 is not decoded and not
	// displayed. This setting is often overriden by DVD2AVI though...
	void	SetDisplayMode(int Display);

	// Go to next video frame. Set Display = false to save time by not displaying the frame.
	// Useful for seeking.
	void	GoToNextVideoFrame(bool Display = true);

	// Go to previous video frame. Set Display = false to save time by not displaying the frame.
	// Useful for seeking.
	void	GoToPreviousVideoFrame(bool Display = true);

	// This opens the video file, goes to the desired sector, applies the proper scaling and dumps
	// the bimap into the desired file.
	int		SaveToBMPFile(char* VideoFileName, int Sector, float Xfactor, float Yfactor, 
		char* BMPFileName);

	// You shouldn't have to call this. It merely refreshes the video image. Can be useful sometimes.
	void	RefreshVideo(bool Refresh = true);

	// This will tell you if the video is currently playing.
	bool	IsVideoRunning();

	// This will get the sector of the frame currently displayed. Sectors are cumulated across VOB files.
	// In other words, at the start of the second VOB file, GetCurrentSector() will return the size of the
	// first VOB file in sectors.
	long	GetCurrentSector();

	// This returns the last sector of the last VOB file.
	long	GetLastSector();

	// This stops the thread and quickly releases the direct-draw ressources.
	void	QuickRelease();

// This changes INIT_X and INIT_Y values.
	void    SetVideoPosition(int PositionX, int PositionY);

	// This changes true playback rate flag.
	void	PlaybackActualRate(BOOL Fps);

	// Call this to show or hide the info panel, and set its position.
	void	ShowInfo(bool Show);
	void	SetInfoPosition(int XPos, int YPos);
	void	GetInfoPosition(int &XPos, int &YPos);

	// This returns the VOB ID and Cell ID of the current nav pack.
	void	GetVobCellID(int &VobID, int &CellID);
	// This returns the number of buttons declared in the current nav pack.
	int		GetNumButtons();

	// There return the width and height of the coded picture in the video.
	int		GetCodedPictureWidth();
	int		GetCodedPictureHeight();

	// Use this to draw buttons or not...
	void	SetDrawButtons(bool DrawThem, COLORREF Color = RGB(0,255,0));
	bool	GetDrawButtons();

protected:

};

















#endif